@@ -1,7 +1,7 @@
-from ecl2df import satfunc, pvt, EclFiles
-
 from pathlib import Path
 
+from ecl2df import satfunc, pvt, EclFiles
+
 
 def extract_pvt(case_loc):
     ecl_files = EclFiles(case_loc)
@@ -14,7 +14,7 @@ def extract_relperm(case_loc):
 
 
 def extract_size(case_loc):
-    x_files = Path(case_loc).rglob(f"*.X*")
+    x_files = Path(case_loc).rglob("*.X*")
     count = 0
     min = 10000000
     max = -1
